#[repr(u8)]pub enum Oesel {
STANDARD = 0,
RS_485 = 1,
}Variants
STANDARD = 0
Standard. The RTS signal is used as the standard flow control function.
RS_485 = 1
RS-485. The RTS signal configured to provide an output enable signal to control an RS-485 transceiver.
Implementations