#[repr(u8)]pub enum Rxpol {
STANDARD = 0,
INVERTED = 1,
}Variants
STANDARD = 0
Standard. The RX signal is used as it arrives from the pin. This means that the RX rest value is 1, start bit is 0, data is not inverted, and the stop bit is 1.
INVERTED = 1
Inverted. The RX signal is inverted before being used by the USART. This means that the RX rest value is 0, start bit is 1, data is inverted, and the stop bit is 0.
Implementations