nxp-pac

Crates

git

Versions

mimxrt685s_cm33

Flavors

Txpol

Enum Txpol 

#[repr(u8)]
pub enum Txpol { STANDARD = 0, INVERTED = 1, }

Variants



STANDARD = 0

Standard. The TX signal is sent out without change. This means that the TX rest value is 1, start bit is 0, data is not inverted, and the stop bit is 1.



INVERTED = 1

Inverted. The TX signal is inverted by the USART before being sent out. This means that the TX rest value is 0, start bit is 1, data is inverted, and the stop bit is 0.

Implementations

Source

impl Txpol

pub const fn from_bits(val: u8) -> Txpol

pub const fn to_bits(self) -> u8